mathtools.BoundedObject
=======================

.. inheritance-diagram:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject
   :private-bases:

.. autoclass:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_closed

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_half_closed

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_half_open

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_open

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_left_closed

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_left_open

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_right_closed

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.is_right_open

Special Methods
---------------

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.BoundedObject.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
